/*******************************************************************************
 * Copyright (C) 2010  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 *******************************************************************************/
package org.ow2.orchestra.console.GWTConsole.client.Commons;

import com.google.gwt.event.dom.client.MouseOutEvent;
import com.google.gwt.event.dom.client.MouseOutHandler;
import com.google.gwt.event.shared.HandlerRegistration;


/**
 * This class is useful to create mouseout handler in mouseover handler to avoid bug in events order.
 * 
 * @author Jean-Yves Goubet
 *
 */
public final class MouseOutHandlerWithHandlerRegistration implements MouseOutHandler {

  private final Object object;
  private SpecialGrid grid;
  private HandlerRegistration handlerRegistration;

  
  /**
   * Constructor of the class
   * 
   * @author Jean-Yves Goubet
   * @param object : the object concerned
   * @param grid : the grid to add the object 
   * 
   */
  public MouseOutHandlerWithHandlerRegistration(Object object, SpecialGrid grid) {
    this.object = object;
    this.grid = grid;
  }
  
  
  /**
   * Method called on mouseOut event
   * 
   * @author Jean-Yves Goubet
   * @param cursorPosition : the position of the cursor
   * 
   */
  public void onMouseOut(MouseOutEvent cursorPosition) {
    if (object instanceof RowLabel) {
      grid.changeRowStyle(((RowLabel)object).getRowIndex(),"");
    } else if (object instanceof TitleLabel) {
      grid.getCellFormatter().setStyleName(0, ((TitleLabel)object).getColumnIndex(), "titleStyle");
    } else if (object instanceof IndexImage) {
      grid.getCellFormatter().setStyleName(0, ((IndexImage)object).getColumnIndex(), "titleStyle");
    } else if (object instanceof IndexFocusPanel) {
      if (((IndexFocusPanel)object).getColumnIndex() == -1) {
        grid.changeRowStyle(((IndexFocusPanel)object).getRowIndex(),"");
      } else {
        grid.getCellFormatter().setStyleName(0, ((IndexFocusPanel)object).getColumnIndex(), "titleStyle");
      }
    }
  }
  
  
  /**
   * Setter of the handlerRegistration parameter
   * 
   * @author Jean-Yves Goubet
   * @param handlerRegistration : the handlerRegistration parameter
   * 
   */
  protected void setHandlerRegistration(HandlerRegistration handlerRegistration) {
    this.handlerRegistration = handlerRegistration;
  }
}
