/*******************************************************************************
 * Copyright (C) 2010  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 *******************************************************************************/
package org.ow2.orchestra.console.GWTConsole.client.ListProcess;

import com.google.gwt.core.client.GWT;
import com.google.gwt.event.shared.HandlerManager;

import org.ow2.orchestra.console.GWTConsole.client.Event.ViewRefreshEvent;
import org.ow2.orchestra.console.GWTConsole.client.Event.ViewRefreshHandler;
import org.ow2.orchestra.console.GWTConsole.client.Tab.PTab;
import org.ow2.orchestra.console.GWTConsole.client.TabLayoutPanel.PTabLayoutPanel;


/**
 * Class that contains the presenter part of ListProcess.
 *
 * @author Jean-Yves Goubet
 *
 */
public class PListProcess {

  /**
   * View interface to manage the UI objects, the string representing the grid title, and different constants
   *
   * @author Jean-Yves Goubet
   */
  private VListProcessIF view;
  protected int currentIndex = -1;

  /**
   * The constructor of class PListProcess
   *
   * @author Jean-Yves Goubet
   * @param lp : the interface representing the view of the class
   * @param tabLayoutPanel : the panel for tabs
   *
   */
  public PListProcess(final VListProcessIF lp, final PTabLayoutPanel presenterTabLayoutPanel, final HandlerManager eventBus) {
    //
    this.bindingView(lp);
    //
    this.addViewRefreshHandlerToBus(eventBus);
    this.view.getListProcessGrid().setHandlerManager(eventBus);
    //
    this.view.getListProcessGrid().setPresenterTabLayoutPanel(presenterTabLayoutPanel);
    this.view.getListProcessGrid().setDebugId();
    //
    this.view.getListProcessGrid().setStringLimitSize(10, 15, 50, "...");
    //
    this.view.getListProcessGrid().refreshCurrentList();
    //
    GWT.log("PListProcess - Constructor : PListProcess correctly instantiated");
  }


  /**
   * Wait refresh event on the eventBus to launch refreshCurrentList
   *
   * @author Jean-Yves Goubet
   *
   */
  private void addViewRefreshHandlerToBus(final HandlerManager eventBus) {
    eventBus.addHandler(ViewRefreshEvent.TYPE, new ViewRefreshHandler() {
      public void onRefresh(final ViewRefreshEvent viewRefreshEvent) {
        if (viewRefreshEvent.getElementType() == PTab.Type.LIST_PROCESS_ACTIVITY) {
          PListProcess.this.refreshCurrentList();
//System.out.println("Je suis l'onglet de process et je me refresh !");
        }
      }
    });
  }

  /**
   * Attach our interface of the view with the real class.
   *
   * @author Jean-Yves Goubet
   * @param lp : interface that represents the view of the class
   *
   */
  private void bindingView(final VListProcessIF lp) {
    this.view = lp;
  }

  /**
   * Call the refresh function of the grid.
   * Use by the DeployProcess presenter
   *
   * @author Jean-Yves Goubet
   *
   */
  public void refreshCurrentList() {
    this.view.getListProcessGrid().refreshCurrentList();
  }

  /**
   * Get method of the view.
   *
   * @author Jean-Yves Goubet
   *
   */
  public VListProcessIF getView() {
    return this.view;
  }
}

